@@ -13,12 +13,18 @@
 
 getTitleSection <- function(protein) {
   #Return title section from an S4 Protein object
-  if(pryr::otype(protein) == "S4") {
-    return(protein@header)
-  }
+  # if(pryr::otype(protein) == "S4") {
+  #   return(protein@header)
+  # }
 
   #Return title section from an S3 Protein object
-  if(pryr::otype(protein) == "S3") {
+  # if(pryr::otype(protein) == "S3") {
+  #   return(protein$header)
+  # }
+
+  if(isS4(protein)) {
+    return(protein@header)
+  } else {
     return(protein$header)
   }
 }
