@@ -16,15 +16,17 @@ write_viz <- function(image, path = "my_image", format = "png") {
   #need to add a check for format parameter
 
   #If it is a trellis object, save it using regular methods
-  if(class(image) == "trellis") {
-    lattice::trellis.device(device = format,
+  # if(class(image) == "trellis") {
+  if(is(image, "trellis")) {
+      lattice::trellis.device(device = format,
                             filename = paste(getwd(), "/", path, ".", format, sep = ""))
     print(image)
     dev.off()
   }
 
   #If it is a magick object, save it using magick image_write function
-  if(class(image) == "magick-image") {
+  # if(class(image) == "magick-image") {
+  if(is(image, "magick-image")) {
     magick::image_write(image, paste(path, ".", format, sep = ""), format)
   }
 }
